;; init.lsp - newLISP initialization file
;; gets loaded automatically on newLISP startup
;; newLISP looks for it in: /usr/share/newlisp/init.lsp
;;
;; defines some useful macros, none of these
;; are required in the other sample programs
;; but some implement forms frequently used
;; in other LISPs
;;
;; v.8.4.3
;;
;; fixed a wrong logic in conditional making of defun macro
;;
;; macro for 'defun' like in other LISPs
;; usage: (defun foo (x y z) body1 body2 ... ) 
;;
;;
(if (not defun) ; loading twice would fail because of constant
  (begin
    (define-macro (defun _func-name _arguments)
      (set _func-name (append 
        '(lambda ) 
         (list _arguments)
         (args))))

    (constant (global 'defun))))

;; edits a function
;;
;; usage: (edit foo)
;;
;; this will open and edit window for editing
;; a functioon called "foo". After saving and 
;; exiting the editor newLISP will reload the
;; function, which is also available in a file 
;; with the same name. Only for unix like OSs
;;

(if (< (& 0xF (last (sys-info))) 5)
  (begin
    (define-macro (edit _func)
	(save (string _func) _func)
	(! (string "/usr/bin/vi " _func))
	(load (string _func)))
	(global 'edit)))


(constant (global '$HOME) (or (env "HOME") (env "USERPROFILE") (env "DOCUMENT_ROOT")))
(if $HOME (load (append $HOME "/.init.lsp")))

;;;; end of file ;;;;


